==> crm-commom-vo-1.3.0.6.51.release.jar: com/biz/crm/nebular/activiti/task/req/TaskQueryReqVO.java <==
package com.biz.crm.nebular.activiti.task.req;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.nebular.activiti.act.resp.TaProxyProcessReqVo;
import com.biz.crm.nebular.mdm.PageVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import jdk.internal.dynalink.linker.LinkerServices;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * @author weston
 * @date 2020-11-25
 */
@Data
@Builder
@Accessors(chain = true)
@ApiModel(value = "TaskQueryReqVO", description = "任务节点查询请求VO")
@AllArgsConstructor
@NoArgsConstructor
@CrmColumnResolve
public class TaskQueryReqVO extends PageVo {

    @ApiModelProperty(value = "用户编码", required = true)
    private String userCode;

    @ApiModelProperty(value = "用户岗位编码")
    private String positionCode;

    @ApiModelProperty(value = "标题,模糊查询")
    private String title;

    @ApiModelProperty(value = "表单业务类型")
    private String costType;

    @ApiModelProperty(value = "表单来源业务系统")
    private String formType;

    @ApiModelProperty("表单类型二级编码")
    private String smallType;

    @ApiModelProperty("状态编码,2-审批中，4-驳回")
    private String status;

    @ApiModelProperty("流程名称")
    private String processName;

    @ApiModelProperty("表单编号")
    private String formNo;

    @ApiModelProperty("表单名称")
    private String formTitle;

    @ApiModelProperty("业务编码")
    private String businessCode;

    @ApiModelProperty("发起者姓名")
    private String startUserName;

    @ApiModelProperty("岗位编码列表")
    private List<String> positionCodes;

    /**
     * 代理审批流程
     */
    private List<TaProxyProcessReqVo> proxyProcessReqVos;
}

==> crm-commom-vo-1.3.0.6.99.release.jar: com/biz/crm/nebular/activiti/task/req/TaskQueryReqVO.java <==
package com.biz.crm.nebular.activiti.task.req;

import com.biz.crm.config.CrmColumnResolve;
import com.biz.crm.nebular.activiti.act.resp.TaProxyProcessReqVo;
import com.biz.crm.nebular.mdm.PageVo;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @author weston
 * @date 2020-11-25
 */
@Data
@Builder
@Accessors(chain = true)
@ApiModel(value = "TaskQueryReqVO", description = "任务节点查询请求VO")
@AllArgsConstructor
@NoArgsConstructor
@CrmColumnResolve
public class TaskQueryReqVO extends PageVo {

    @ApiModelProperty(value = "用户编码", required = true)
    private String userCode;

    @ApiModelProperty(value = "用户岗位编码")
    private String positionCode;

    @ApiModelProperty(value = "标题,模糊查询")
    private String title;

    @ApiModelProperty(value = "表单业务类型")
    private String costType;

    @ApiModelProperty(value = "表单来源业务系统")
    private String formType;

    @ApiModelProperty("表单类型二级编码")
    private String smallType;

    @ApiModelProperty("状态编码,2-审批中，4-驳回")
    private String status;

    @ApiModelProperty("流程名称")
    private String processName;

    @ApiModelProperty("表单编号")
    private String formNo;

    @ApiModelProperty("表单名称")
    private String formTitle;

    @ApiModelProperty("业务编码")
    private String businessCode;

    @ApiModelProperty("发起者姓名")
    private String startUserName;

    @ApiModelProperty("岗位编码列表")
    private List<String> positionCodes;

    @ApiModelProperty("表单类型列表")
    private List<String> formTypeList;

    @ApiModelProperty("查询流程发起时间(开始)")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss" )
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date initiateStartTime;

    @ApiModelProperty("查询流程发起时间(结束)")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss" )
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date initiateEndTime;

    @ApiModelProperty("查询流程处理时间(开始)")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss" )
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date processStartTime;

    @ApiModelProperty("查询流程处理时间(结束)")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss" )
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date processEndTime;

    /**
     * 代理审批流程
     */
    private List<TaProxyProcessReqVo> proxyProcessReqVos;
}
